@@ -1,6 +1,6 @@
 """Hyperlinks for pydantic models"""
 
-__version__ = "0.1.2"
+__version__ = "0.2"
 
 from .href import Href, Referrable
-from .model import BaseReferrableModel
+from .model import BaseReferrableModel, PrimaryKey
